@@ -126,7 +126,7 @@ class TeiReader(XMLReader):
             entities = []
             for x in ner_dicts:
                 if x['text'] != "":
-                    for m in re.finditer(x['text'], plain_text):
+                    for m in re.finditer(re.escape(x['text']), plain_text):
                         entities.append([m.start(), m.end(), x['ne_type']])
             entities = [item for item in set(tuple(row) for row in entities)]
             entities = sorted(entities, key=lambda x: x[0])
@@ -192,10 +192,12 @@ class TeiEnricher(TeiReader):
         for x in mentions:
             event_node = ET.Element(f"{{{tei_ns}}}event")
             event_node.set('type', 'mentioned')
-            event_node.text = event_title
+            event_p_node = ET.Element(f"{{{tei_ns}}}p")
+            event_p_node.text = event_title
             title_node = ET.Element(f"{{{tei_ns}}}title")
             title_node.text = x['doc_title']
-            event_node.append(title_node)
+            event_p_node.append(title_node)
+            event_node.append(event_p_node)
             lnkgrp_node = ET.Element(f"{{{tei_ns}}}linkGrp")
             lnk_node = ET.Element(f"{{{tei_ns}}}link")
             lnk_node.set('type', 'ARCHE')
